

*Import the county level firm statistics
import excel using "CoE_county_breakdown", first clear
keep county_name count_county  
label variable count_county "Number of firms per county"
save "CoE_county_breakdown", replace

*Import the geo-location and population figure of major Kenian cities
import excel using "cities_population", clear first
*Rank cities according to their size
label variable peri_urban "Peri urban population"
label variable core_urban "Core urban population"
save "cities_population", replace

*Import shapefile and related information in Stata
shp2dta using "ken_admbnda_adm1_iebc_20180607", database(ken_counties) coordinates(kencoord) genid(county_id) replace

*Clean the county names in the newly created "ken_counties" file containing the list of all counties
use ken_counties, clear
rename ADM1_EN county_name
replace county_name=upper(county_name)  // ensures county names upper case in both data sets

*Now merge with the figures from the Census of Establishments
merge 1:1 county_name using "CoE_county_breakdown" // merge both data sets by county name
cap drop _merge

*Now we are ready to map the density of private sector activity in Kenya
spmap count_county using kencoord, id(county_id) legend(on) fcolor(Greens2) /// *specify base map (kencoord) and variable identifying relevant geographic units (county_id)
clbreaks(0 1001 2001 3001 5001 10001 50000) clmethod(custom) /// alter categories used for colourcoding
legend(label(2 "0 to 1000") label(3 "1001 to 2000")  label(4 "2001 to 3000" )  label(5 "3001 to 5000" ) label(6 "5001 to 10000" ) label(7 "10000+" )) // change default labels (just cosmetics really)
graph export establishments_census.png, replace


*As a next step we might want to add the information on the size and location of the largest cities_population
spmap count_county using kencoord, id(county_id) point(data("cities_population")  xcoord(longitude) ycoord(latitude) proportional(population)  fcolor(orange) ocolor(black) select(keep if population>350000) legenda(on) leglabel(Cities with 350,000 or more inhabitants)) legend(on) fcolor(Blues2) clbreaks(0 1001 2001 3001 5001 10001 50000) clmethod(custom) legend(label(2 "0 to 1,000") label(3 "1,001 to 2,000")  label(4 "2,001 to 3,000" )  label(5 "3,001 to 5,000" ) label(6 "5,001 to 10,000" ) label(7 "10,000+" )) 
graph export establishments_census_cities.png, replace

spmap count_county using kencoord, id(county_id) diagram(data("cities_population")  xcoord(longitude) ycoord(latitude) variables(core_urban peri_urban) fcolor(orange) legenda(on) select(drop if city=="Nairobi"))   legend(on) fcolor(Blues2) clbreaks(0 1001 2001 3001 5001 10001 50000) clmethod(custom) legend(label(2 "0 to 1,000") label(3 "1,001 to 2,000")  label(4 "2,001 to 3,000" )  label(5 "3,001 to 5,000" ) label(6 "5,001 to 10,000" ) label(7 "10,000+" ) )
graph export peri_core_urban.png, replace

*Little add-on
use cities_population, clear
*Transform the geographic latitude and longitude into cartesian coordinates 
geo2xy latitude longitude , generate(y_lat x_long) proj(mercator, 6378137 298.257223563 0)
